#include <Arduino.h>
#include <M5Stack.h>
#include <SPI.h>
#include <SdFat.h>

// ********************************************************************
//  M5Stackの内蔵TFカード/SDカードスロットの内容を消去するプログラム
//  
//  必要な機材
//  ・M5Stack
//  
//  This software is distributed under the license of NYSL.
//  http://www.kmonos.net/nysl/
// ********************************************************************
//
// このプログラムはgreimanさんのSdFatライブラリを使用しています。
// ( https://github.com/greiman/SdFat )
// このプログラムをコンパイルするためには、SdFatライブラリの一部を修正する
// 必要があります。
// FatLib/FatVolume.hの336行目付近で定義されている
// 「FatFile* vwd() {return &m_vwd;}」のスコープをprivateからpublicに
// なるよう修正してください。
//
// ■修正例 
// public:
//  FatFile* vwd() {return &m_vwd;}
//

#define SD_CONFIG SdSpiConfig(TFCARD_CS_PIN, SHARED_SPI, SD_SCK_MHZ(25))

SdFat32 sd;

void confirm() {

  M5.Lcd.fillScreen(BLACK);

  M5.Lcd.setTextColor(WHITE);
  M5.Lcd.setTextSize(3);

  M5.Lcd.setCursor(0, 0);
  M5.Lcd.print("Erase all files?");

  M5.Lcd.setCursor(0, 40);
  M5.Lcd.println("Yes=A / NO=C");

  M5.Speaker.beep();
  delay(50);
  M5.Speaker.mute();
}

void setup() {

  M5.begin();

  M5.Lcd.fillScreen(BLACK);
  M5.Lcd.setTextColor(WHITE);
  M5.Lcd.setTextSize(3);

  M5.Lcd.setCursor(0, 0);
  M5.Lcd.print("SD Card Eraser");

  M5.Speaker.beep();
  delay(50);
  M5.Speaker.mute();

  M5.Lcd.setCursor(0, 20);
  M5.Lcd.print("Init...");

  // SDカードの初期化
  if (!sd.begin(SD_CONFIG)) {
    sd.initErrorHalt();
    M5.Lcd.fillScreen(RED);
    M5.Lcd.setCursor(0, 0);
    M5.Lcd.print("Init Error");
    return;
  }

  M5.Speaker.beep();
  delay(50);
  M5.Speaker.mute();

  confirm();
}


void loop() {
  
  M5.update();

  // ボタン押下待ち
  if (M5.BtnA.isReleased() && M5.BtnC.isReleased()) { return; }
  if (M5.BtnC.wasPressed()) {
    M5.Lcd.print("Cancelled");
    delay(500);
    confirm();
    return;
  }

  M5.Lcd.fillScreen(RED);
  M5.Lcd.setCursor(0, 0);
  M5.Lcd.println("Erasing...");
  
  // SDカードの内容を消す
  sd.vwd()->rmRfStar();

  M5.Speaker.beep();
  delay(100);
  M5.Speaker.mute();
  delay(500);

  confirm();
}